==> qewd-ripple-2.27.0.tgz: package/lib/headings/counts.js <==
/*

 ----------------------------------------------------------------------------
 | qewd-ripple: QEWD-based Middle Tier for Ripple OSI                       |
 |                                                                          |
 | Copyright (c) 2016-17 Ripple Foundation Community Interest Company       |
 | All rights reserved.                                                     |
 |                                                                          |
 | http://rippleosi.org                                                     |
 | Email: code.custodian@rippleosi.org                                      |
 |                                                                          |
 | Author: Rob Tweed, M/Gateway Developments Ltd                            |
 |                                                                          |
 | Licensed under the Apache License, Version 2.0 (the "License");          |
 | you may not use this file except in compliance with the License.         |
 | You may obtain a copy of the License at                                  |
 |                                                                          |
 |     http://www.apache.org/licenses/LICENSE-2.0                           |
 |                                                                          |
 | Unless required by applicable law or agreed to in writing, software      |
 | distributed under the License is distributed on an "AS IS" BASIS,        |
 | WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
 | See the License for the specific language governing permissions and      |
 |  limitations under the License.                                          |
 ----------------------------------------------------------------------------

17 May 2017

*/

var heading = {
  name: 'counts',
  headingTableFields: ['diagnosesCount', 'diagnosesDate', 'ordersCount', 'ordersDate', 'resultsCount', 'resultsDate', 'vitalsCount', 'vitalsDate'],

  get: {

    transformTemplate: {
      diagnosesCount: '{{diagnosesCount}}',
      diagnosesDate:  '{{diagnosesDate}}',
      ordersCount:    '{{ordersCount}}',
      ordersDate:     '{{ordersDate}}',
      resultsCount:   '{{resultsCount}}',
      resultsDate:    '{{resultsDate}}',
      vitalsCount:    '{{vitalsCount}}',
      vitalsDate:     '{{vitalsDate}}',
      source:         '=> getSource()',
      sourceId:       '=> getCountsSource()',
    }
  }
};

module.exports = heading;

==> qewd-ripple-2.29.3.tgz: package/lib/headings/counts.js <==
/*

 ----------------------------------------------------------------------------
 | qewd-ripple: QEWD-based Middle Tier for Ripple OSI                       |
 |                                                                          |
 | Copyright (c) 2016-17 Ripple Foundation Community Interest Company       |
 | All rights reserved.                                                     |
 |                                                                          |
 | http://rippleosi.org                                                     |
 | Email: code.custodian@rippleosi.org                                      |
 |                                                                          |
 | Author: Rob Tweed, M/Gateway Developments Ltd                            |
 |                                                                          |
 | Licensed under the Apache License, Version 2.0 (the "License");          |
 | you may not use this file except in compliance with the License.         |
 | You may obtain a copy of the License at                                  |
 |                                                                          |
 |     http://www.apache.org/licenses/LICENSE-2.0                           |
 |                                                                          |
 | Unless required by applicable law or agreed to in writing, software      |
 | distributed under the License is distributed on an "AS IS" BASIS,        |
 | WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
 | See the License for the specific language governing permissions and      |
 |  limitations under the License.                                          |
 ----------------------------------------------------------------------------

28 June 2017

*/

var heading = {
  name: 'counts',
  headingTableFields: ['diagnosesCount', 'diagnosesDate', 'ordersCount', 'ordersDate', 'resultsCount', 'resultsDate', 'vitalsCount', 'vitalsDate'],

  get: {

    transformTemplate: {
      diagnosesCount: '=> integer(diagnosesCount)',
      diagnosesDate:  '{{diagnosesDate}}',
      ordersCount:    '=> integer(ordersCount)',
      ordersDate:     '{{ordersDate}}',
      resultsCount:   '=> integer(resultsCount)',
      resultsDate:    '{{resultsDate}}',
      vitalsCount:    '=> integer(vitalsCount)',
      vitalsDate:     '{{vitalsDate}}',
      source:         '=> getSource()',
      sourceId:       '=> getCountsSource()',
    }
  }
};

module.exports = heading;
